Interactions
------------

.. py:module:: pyslet.qtiv2.interactions


..	autoclass:: Interaction
	:members:
	:show-inheritance:


..	autoclass:: InlineInteraction
	:members:
	:show-inheritance:


..	autoclass:: BlockInteraction
	:members:
	:show-inheritance:


..	autoclass:: Prompt
	:members:
	:show-inheritance:


..	autoclass:: Choice
	:members:
	:show-inheritance:


..	autoclass:: AssociableChoice
	:members:
	:show-inheritance:


Simple Interactions
~~~~~~~~~~~~~~~~~~~

..	autoclass:: ChoiceInteraction
	:members:
	:show-inheritance:


..	autoclass:: OrderInteraction
	:members:
	:show-inheritance:


..	autoclass:: SimpleChoice
	:members:
	:show-inheritance:


..	autoclass:: AssociateInteraction
	:members:
	:show-inheritance:


..	autoclass:: MatchInteraction
	:members:
	:show-inheritance:


..	autoclass:: SimpleAssociableChoice
	:members:
	:show-inheritance:


..	autoclass:: SimpleMatchSet
	:members:
	:show-inheritance:


..	autoclass:: GapMatchInteraction
	:members:
	:show-inheritance:


..	autoclass:: Gap
	:members:
	:show-inheritance:


..	autoclass:: GapChoice
	:members:
	:show-inheritance:


..	autoclass:: GapText
	:members:
	:show-inheritance:


..	autoclass:: GapImg
	:members:
	:show-inheritance:


Text-based Interactions
~~~~~~~~~~~~~~~~~~~~~~~

..	autoclass:: InlineChoiceInteraction
	:members:
	:show-inheritance:


..	autoclass:: InlineChoice
	:members:
	:show-inheritance:


..	autoclass:: StringInteractionMixin
	:members:
	:show-inheritance:


..	autoclass:: TextEntryInteraction
	:members:
	:show-inheritance:


..	autoclass:: TextFormat
	:members:
	:show-inheritance:


..	autoclass:: ExtendedTextInteraction
	:members:
	:show-inheritance:


..	autoclass:: HottextInteraction
	:members:
	:show-inheritance:


..	autoclass:: Hottext
	:members:
	:show-inheritance:


Graphical Interactions
~~~~~~~~~~~~~~~~~~~~~~

..	autoclass:: GapImg
	:members:
	:show-inheritance:


..	autoclass:: GapImg
	:members:
	:show-inheritance:


..	autoclass:: GapImg
	:members:
	:show-inheritance:
